program Rdsites
implicit none
!  Reads from EMEP input file (e.g. sites.0107 say), and provides various 
!  outputs for a chosen pollutant:
!

character(len=100) :: infile   ! for GetArg
integer, parameter :: MAXDIM = 600   ! No. variables and /or sites 
character(len=20), dimension(MAXDIM) :: sitename
character(len=20), dimension(MAXDIM) :: specname
real             , dimension(MAXDIM) :: xin
real             , dimension(31,0:23) :: data
character(len=20) :: insite, wpoll, wsite
integer :: i, yy, mm, dd, hh, isite, nsites, n, nspec, freq
integer :: wanted_site, wanted_spec, last_day
integer :: io_in, io_dmax, io_dmean, io_vals, io_hrly, io_snam, io_dates

   if ( iargc() > 0 ) then
     call getarg(1,infile)
     call getarg(2,wsite)
     call getarg(3,wpoll)
     print *, "Input argument: ", infile
     if ( len_trim(wsite)>0 ) print *, "Site wanted ", wsite
     if ( len_trim(wpoll)>0 ) print *, "Poll wanted ", wpoll
   end if
   if ( infile == "-h"  .or. iargc() == 0 ) then
     print *, "Usage: Rd_sites sites.mmyy  [site_name] [poll_name]"
     print *, " => "
     print *, "     SITES.dmax     - dailymax values  "
     print *, "     SITES.dmean    - dailymean values  "
     print *, "     SITES.hrly     - all hourly values"
     print *, "     SITES.sname    - name of site chosen"
     print *, "     SITES.vals     - all values, printed 24 hourly values per line"
     stop
   end if

   io_in = 10
   open(io_in,file=infile)


   read(unit=io_in,fmt=*)  nsites
   read(unit=io_in,fmt=*)  freq
!============================================================================
   do isite = 1, nsites
     read(unit=io_in,fmt=*)   sitename(isite)
     if ( len_trim(wsite)>0 ) then
        if ( trim(wsite)==trim( sitename(isite))) wanted_site = isite 
     else
        print *, isite, sitename(isite)
     end if
   end do
   if ( len_trim(wsite)==0 ) then
      print *, "Choose site"
      read(unit=5,fmt=*) wanted_site
   end if
   if ( wanted_site <1) then
     print *, "NO SITE OF THAT NAME, START AGAIN!"
     do isite = 1, nsites
        print *, isite, sitename(isite)
     end do
     stop
   end if
print *, "NSITES ", nsites, "FREQ ", freq, "WANTED_SITEXX ", wanted_site, trim(wsite), trim(sitename(wanted_site))
   print *, "Chose site", sitename(wanted_site)
!stop
!============================================================================
   wanted_spec = -1
   read(unit=io_in,fmt=*) nspec
   do i = 1, nspec
     read(unit=io_in,fmt=*) n, specname(n)
     if ( len_trim(wpoll)>0 ) then
       if ( trim(wpoll)==trim( specname(n))) wanted_spec = i
     else
       print *,           n, specname(n)
     end if
   end do
   if ( len_trim(wpoll)==0 ) then
     print *, "Choose species"
     read(unit=5,fmt=*) wanted_spec
   end if
   if ( wanted_spec < 1 ) then
     print *, "NO POLL OF THAT NAME, START AGAIN!"
     print "(5(i4,a1,a))", (i, " ", trim(specname(i)), i=1,nspec)
     stop
   end if
   print *, "Site ", wanted_site, " Poll ", specname(wanted_spec)
!============================================================================
   io_dmax = 11
   open(io_dmax,file="SITES.dmax")
   io_vals = 12
   open(io_vals,file="SITES.vals")
   io_hrly = 14
   open(io_hrly,file="SITES.hrly")
   io_dmean = 15
   open(io_dmean,file="SITES.dmean")
   io_snam= 16
   open(io_snam,file="SITES.sname")
   io_dates = 17
   open(io_dates,file="SITES.dates")
!============================================================================



!Data bits start with e.g.:
!AZOF                 2003  8  1  0    0
! 3.204E+01 8.467E-04 4.002E-01 1.769E-01 8.190E-30
! 1.234 ..... etc.

   data(:,:) = 0.0
   do while (.true.)
     do isite = 1, nsites
      read(unit=io_in,fmt=*,err=100,end=100) insite, yy, mm, dd, hh
      read(unit=io_in,fmt=*,err=100,end=100) (xin(i), i = 1, nspec)
      if (isite == wanted_site ) then
         last_day = dd
         data(dd,hh) = xin(wanted_spec)
         if( dd == 1 .and. hh == freq) then
                 data(dd,0) = data(dd,hh)
         end if
      end if
     end do
   end do
100 continue

    write(unit=io_snam,fmt="(a20)") sitename(wanted_site)
    do dd = 1, last_day

       ! The file SITES.vals has all values for one day in one record.
       ! We format with integers if possible, otherwise es

        if( maxval(data) < 1.0 ) then
          write(unit=io_vals,fmt="(24es9.2)") ( data(dd,hh), hh= 0,23)
        else if( maxval(data) < 100.0 ) then
          write(unit=io_vals,fmt="(24i3)") ( int(data(dd,hh)), hh= 0,23)
        else
          write(unit=io_vals,fmt="(24i5)") ( int(data(dd,hh)), hh= 0,23)
        end if

       ! Max, Mean
        write(unit=io_dmax,fmt="(g14.4)") maxval(data(dd,:))
        write(unit=io_dmean,fmt="(g14.4)") sum(data(dd,:))/24.0
        write(unit=io_dates,fmt="(3i4)") yy, mm, dd
       ! SITES.hrly
        do hh = 0, 23, freq
           write(unit=io_hrly,fmt="(3i3,g14.5)") mm,dd,hh,data(dd,hh)
        end do
    end do

end program Rdsites
