implicit none
!  Reads from input file (e.g. model file sondes.0107 say), and provides 
!  various outputs for a chosen pollutant.
!
!       SONDES.vals - provides output for each hour (by row), with here NK=15
!                     columns representing 15 height levels.


character(len=100) :: infile   ! for GetArg
integer, parameter :: IO_5=5, IO_IN = 10,  &
   IO_SNAM=12, IO_DMAX=14, IO_MMEAN=15, IO_VALS=16, IO_DATES= 17, &
   NK = 20, &   ! Number of vertical levels to be printed
   MAX_SITES= 100, MAX_SPEC = 200
character(len=20), dimension(MAX_SITES) :: sitename
character(len=20), dimension(MAX_SPEC) :: specname
real             , dimension(20) :: xin
real             , dimension(31,0:23,20) :: data
real :: maxx = -9.99e19   ! Max xin value found in 1:NK range 
character(len=20) :: fmt
character(len=20) :: insite, wpoll, wsite
integer :: yy, mm, dd, hh, freq, last_day
integer :: i, k, n, nspec, nsites, isite, ispec
integer :: wanted_site, wanted_spec
integer :: nlevels = 20
logical :: DEBUG = .false.

   if ( iargc() > 0 ) then
     call getarg(1,infile)
     call getarg(2,wsite)
     call getarg(3,wpoll)
     print *, "Input argument: ", infile
     if ( len_trim(wsite)>0 ) print *, "Site wanted ", wsite
     if ( len_trim(wpoll)>0 ) print *, "Poll wanted ", wpoll

   end if
   if ( infile == "-h" .or. iargc() == 0 ) then
     print *, "Usage: Rd_sondes sondes.mmyy  [site_name] [poll_name]"
     print *, " => "
     print *, "     SONDES.dmax      - daily-max values for NK (e.g. 15) levels"
     print *, "     SONDES.mmean     - monthly-mean values for NK (e.g. 15) levels"
     print *, "     SONDES.sname    - name of site chosen"
     print *, "     SONDES.vals     - all values, printed 24 hourly values per line"
     print *, "------------------------------"
     print *, "See code for details of formats"
     stop
   end if

  !In
   open(IO_IN,file=infile)

  !Out
   open(IO_VALS,file="SONDES.vals")
   open(IO_SNAM,file="SONDES.sname")
   open(IO_DMAX,file="SONDES.dmax")
   open(IO_MMEAN,file="SONDES.mmean")
   open(IO_DATES,file="SONDES.dates")

   read(IO_IN,*)  nsites
   read(IO_IN,*)  freq
!============================================================================
   do isite = 1, nsites
     read(unit=io_in,fmt=*)   sitename(isite)
     if ( len_trim(wsite)>0 ) then
        if ( trim(wsite)==trim( sitename(isite))) wanted_site = isite
     else
        print *, isite, sitename(isite)
     end if
   end do
   if ( len_trim(wsite)==0 ) then
      print *, "Choose site"
      read(unit=5,fmt=*) wanted_site
   end if
   if ( wanted_site <1) then
     print *, "NO SITE OF THAT NAME, START AGAIN!"
     do isite = 1, nsites
        print *, isite, sitename(isite)
     end do
     stop
   end if
   print *, "Chose site", sitename(wanted_site)
!============================================================================
  wanted_spec = -1
   read(unit=io_in,fmt=*) nspec
   do i = 1, nspec
     read(unit=io_in,fmt=*) n, specname(n)
     if ( len_trim(wpoll)>0 ) then
       if ( trim(wpoll)==trim( specname(n))) wanted_spec = i
     else
       print *,           n, specname(n)
     end if
   end do
   if ( len_trim(wpoll)==0 ) then
     print *, "Choose species"
     read(unit=5,fmt=*) wanted_spec
   end if
   if ( wanted_spec < 1 ) then
     print *, "NO POLL OF THAT NAME, START AGAIN!"
     print "(5(i4,a1,a))", (i, " ", trim(specname(i)), i=1,nspec)
     stop
   end if
   print *, "Site ", wanted_site, " Poll ", specname(wanted_spec)
!============================================================================

   do while (.true.)
     do isite = 1, nsites
      read(IO_IN,*,err=100,end=100) insite, yy, mm, dd, hh
      if( DEBUG ) print *, insite, yy, mm, dd, hh

      do ispec = 1, nspec
         if ( DEBUG ) print *, "into ispec ", ispec
          read(io_in,*,err=100,end=100) (xin(k), k = 1, nlevels)
        if( DEBUG ) print *, "ok ispec ", ispec, specname(ispec), xin(1), xin(20)
        if (isite == wanted_site .and. ispec == wanted_spec ) then
           last_day = dd
           data(dd,hh,:) = xin(:)
           maxx = max( maxval(xin(1:NK)), maxx )
        end if
      end do ! spec
     end do
   end do
100 continue

    write(IO_SNAM,"(a20)") sitename(wanted_site)
    fmt = "(3i3,30f8.3)"    ! Allow up to 30 fields
    if ( maxx > 1.0e3 ) fmt = "(3i3,30f8.2)"
    if ( maxx > 1.0e4 ) fmt = "(3i3,30es10.2)"

   ! Usually the zeroth hour of the 1st month is not printed. We
   ! make an approximation here:
    data(1,0,:) =  data(1,1,:)

    do dd = 1, last_day

      do hh = 0, 23, freq
        write(IO_VALS,fmt=fmt) mm, dd,hh, (data(dd,hh,k), k= 1, NK )
      end do

      write(IO_DMAX,"(2i4,30es10.3)") mm, dd, (maxval(data(dd,:,k)), k=1,NK)

    end do ! dd

    do k = 1, NK
       write(IO_MMEAN,"(2i4, f10.3)") mm, k, sum(data(:,:,k))/real(last_day)
    end do

end
